@@ -180,6 +180,7 @@ class Tauk:
 
         if len(cls._test_results) > 0:
             for test_result in cls._test_results:
+
                 payload = {
                     'test_status': test_result.status,
                     'test_name': test_result.name,
@@ -224,3 +225,5 @@ class Tauk:
                         "An error occurred trying to make an upload request.")
                     logging.error(request_error)
                     logging.error(response.text)
+                else:
+                    return response.json()
