@@ -52,24 +52,45 @@ def format_appium_log(log_list):
     return output
 
 
-def flatten_desired_capabilities(d, parent_key='', sep='_'):
+def flatten_desired_capabilities(desired_caps, parent_key='', sep='_'):
     items = []
-    for k, v in d.items():
-        new_key = parent_key + sep + k if parent_key else k
-
-        if isinstance(v, MutableMapping):
+    for key, value in desired_caps.items():
+        new_key = parent_key + sep + key if parent_key else key
+        if isinstance(value, MutableMapping):
             items.extend(flatten_desired_capabilities(
-                v, new_key, sep=sep).items())
+                value, new_key, sep=sep).items())
         else:
-            items.append((new_key, v))
+            items.append((new_key, value))
     return dict(items)
 
 
-def get_automation_type(desired_capabilities):
-    if desired_capabilities.get('automationName'):
-        return 'appium'
-    elif desired_capabilities.get('browserName'):
-        return 'selenium'
+def get_automation_type(desired_caps):
+    if desired_caps.get('automationName'):
+        return 'Appium'
+    elif desired_caps.get('browserName'):
+        return 'Selenium'
+    else:
+        return None
+
+
+def get_platform_name(desired_caps):
+    if desired_caps.get('browserName'):
+        return desired_caps.get('browserName').title()
+    elif desired_caps.get('platformName'):
+        mobilePlatformName = desired_caps.get('platformName').lower()
+        if mobilePlatformName == "ios":
+            return "iOS"
+        else:
+            return mobilePlatformName.title()
+    else:
+        return None
+
+
+def get_platform_version(desired_caps):
+    if desired_caps.get('browserVersion'):
+        return desired_caps.get('browserVersion')
+    elif desired_caps.get('platformVersion'):
+        return desired_caps.get('platformVersion')
     else:
         return None
 
